﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using PR_check_UI.Properties;
using System.Xml.Linq;

namespace PR_check_UI
{
    public partial class FrmMain : Form
    {
        #region Ctor

        /// <summary>
        /// 
        /// </summary>
        public FrmMain()
        {
            InitializeComponent();

            // Set here to empty so there is text in the creation and
            // we can see it in Design mode
            this.LblResult.Text = string.Empty;
        }
 
        #endregion

        #region Events

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void FrmMain_Load(object sender, EventArgs e)
        {
            bool XMLValidationPassed = History.Instance.Init();

            if (!XMLValidationPassed)
            {
                string ErrorMsg = string.Format(new StringBuilder("Invalid History file\r\nReplace the {0} file with the original one").Append(
                                                "or change the history file path in the configuration file into valid one\r\n\r\n").Append(
                                                "Bye Bye :)").ToString(),
                                                @Settings.Default.HistoryXmlFile);

                MessageBox.Show(ErrorMsg, "Error", MessageBoxButtons.OK);

                this.Close();
            }
            else
            {
                // Add History to UI
                this.UpdateHistoryInUI();
            }
        }

        /// <summary>
        /// Ckear button clicked
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void BtnClear_Click(object sender, EventArgs e)
        {
            this.TxtBNewRequestSiteURL.Text = string.Empty;
            this.LblResult.Text = string.Empty;
            this.cmbBNewRequestSiteHistory.Text = "";
        }

        /// <summary>
        /// Calculate rank button clicked
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void BtnGetRank_Click(object sender, EventArgs e)
        {
            if (!this.ValidateNewRankRequest())
            {
                return;
            }

            int Rank = Calculator.Instance.GetRank(this.TxtBNewRequestSiteURL.Text);
            string s;

            if (Rank == Settings.Default.ErrorRankValue)
            {
                s = "Error";
            }
            else
            {
                s = string.Format("result: {0}", Rank);

                History.Instance.AddSite(
                    new HistoryItem()
                    {
                        URL = this.TxtBNewRequestSiteURL.Text,
                        Rank = Rank,
                        Date = DateTime.Now
                    });
            }

            this.LblResult.Text = s;

            this.UpdateHistoryInUI();
        }

        /// <summary>
        /// View history button clicked
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void BtnViewHistory_Click(object sender, EventArgs e)
        {
            if (!this.cmbBHistoryRequestSiteHistory.SelectedIndex.Equals(Settings.Default.ErrorRankValue))
            {
                object Selection = this.cmbBHistoryRequestSiteHistory.Items[this.cmbBHistoryRequestSiteHistory.SelectedIndex];
                string URL = Selection.ToString();
                List<HistoryItem> Lst = History.Instance.GetItemsByItemURL(URL);

                Form F = new FrmHistory(URL, Lst);
                F.ShowDialog();
            }
        }

        /// <summary>
        /// Delete from history button clicked
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void BtnHistortDelete_Click(object sender, EventArgs e)
        {
            object Selection = this.cmbBHistoryRequestSiteHistory.Items[this.cmbBHistoryRequestSiteHistory.SelectedIndex];
            string URL = Selection.ToString();
            History.Instance.RemoveItemByURL(URL);

            this.UpdateHistoryInUI();

            this.cmbBHistoryRequestSiteHistory.Text = string.Empty;
        }

        /// <summary>
        /// New request from history - index changed
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void cmbBNewRequestSiteHistory_SelectedIndexChanged(object sender, EventArgs e)
        {
            ComboBox Sender = (sender as ComboBox);
            this.TxtBNewRequestSiteURL.Text = Sender.Items[Sender.SelectedIndex].ToString();
        }

        #endregion

        #region Other methods

        /// <summary>
        /// Validate request
        /// </summary>
        /// <returns></returns>
        private bool ValidateNewRankRequest()
        {
            bool IsValid = true;

            if (this.TxtBNewRequestSiteURL.Text == string.Empty)
            {
                IsValid = false;
                MessageBox.Show("Request URL is empty");
            }
            else if ((this.TxtBNewRequestSiteURL.Text.IndexOf("http://") != 0)
                &&
                (this.TxtBNewRequestSiteURL.Text.IndexOf("https://") != 0))
            {
                IsValid = false;
                MessageBox.Show("URL must start with 'http://' or 'https://'");
            }

            if (this.TxtBNewRequestSiteURL.Text.LastIndexOf("/") != this.TxtBNewRequestSiteURL.Text.Length - 1)
            {
                this.TxtBNewRequestSiteURL.Text += "/";
            }

            return IsValid;
        }

        /// <summary>
        /// Update History lists in UI
        /// </summary>
        private void UpdateHistoryInUI()
        {
            this.cmbBNewRequestSiteHistory.Items.Clear();
            this.cmbBHistoryRequestSiteHistory.Items.Clear();

            foreach (HistoryItem CurrentItem in History.Instance.DistinctSites)
            {
                this.cmbBNewRequestSiteHistory.Items.Add(CurrentItem.URL);
                this.cmbBHistoryRequestSiteHistory.Items.Add(CurrentItem.URL);
            }
        }
 
        #endregion
    }
}
