﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ZedGraph;

namespace PR_check_UI
{
    public partial class FrmHistory : Form
    {
        /// <summary>
        /// Ctor
        /// </summary>
        /// <param name="URL"></param>
        /// <param name="Lst"></param>
        public FrmHistory(string URL, List<HistoryItem> Lst)
        {
            InitializeComponent();
            this.Text = this.Text.Replace("{0}", URL);

            CreateGraph(this.ZGCPRGraph, Lst, URL);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="zgc"></param>
        /// <param name="Lst"></param>
        /// <param name="URL"></param>
        private void CreateGraph(ZedGraphControl zgc, List<HistoryItem> Lst, string URL)
        {
            GraphPane myPane = zgc.GraphPane;

            myPane.XAxis.Type = AxisType.Date;

            // Set the titles and axis labels
            myPane.Title.Text = "Page Rank for " + URL;
            myPane.XAxis.Title.Text = "Date / Time";
            myPane.YAxis.Title.Text = "Rank Value";

            // Make up some data points from the Sine function
            PointPairList list = new PointPairList();

            // Add graph points
            foreach (HistoryItem CurrentItem in Lst)
            {
                double Date = (double)new XDate(CurrentItem.Date);

                list.Add(Date, CurrentItem.Rank);
            }


            // Generate a blue curve with symbols
            LineItem myCurve = myPane.AddCurve( "PR",
                                                list,
                                                Color.Blue,
                                                SymbolType.Circle);

            // Make the symbols opaque by filling them with white
            myCurve.Symbol.Fill = new Fill(Color.Red);

            // Fill the axis background with a color gradient
            myPane.Chart.Fill = new Fill(Color.White, Color.LightGoldenrodYellow, 45F);

            // Fill the pane background with a color gradient
            myPane.Fill = new Fill(Color.White, Color.FromArgb(220, 220, 255), 45F);

            // Calculate the Axis Scale Ranges
            zgc.AxisChange();
        }
    }
}
